"""
Fullscreen Web Display with External URL Injection
A PyQt6-based fullscreen web browser that can receive URLs via external commands.
"""

__version__ = "0.0.1"
__author__ = "Maximilian Erkens"
__email__ = "max@max-erkens.de"

from .main import main

__all__ = ["main"]
